@@ -35,7 +35,6 @@ module Yesod.Static
       -- * Smart constructor
     , static
     , staticDevel
-    , embed
       -- * Combining CSS/JS
       -- $combining
     , combineStylesheets'
@@ -54,6 +53,8 @@ module Yesod.Static
     , publicFiles
       -- * Hashing
     , base64md5
+      -- * Embed
+    , embed
 #ifdef TEST_EXPORT
     , getFileListPieces
 #endif
@@ -100,7 +101,7 @@ import Filesystem (createTree)
 import qualified Data.Text.Lazy as TL
 import qualified Data.Text.Lazy.Encoding as TLE
 import Data.Default
-import Text.Lucius (luciusRTMinified)
+--import Text.Lucius (luciusRTMinified)
 
 import Network.Wai.Application.Static
     ( StaticSettings (..)
@@ -134,8 +135,11 @@ staticDevel dir = do
     hashLookup <- cachedETagLookupDevel dir
     return $ Static $ webAppSettingsWithLookup (F.decodeString dir) hashLookup
 
--- | Produce a 'Static' based on embedding all of the static
--- files' contents in the executable at compile time.
+-- | Produce a 'Static' based on embedding all of the static files' contents in the
+-- executable at compile time.
+--
+-- You should use "Yesod.EmbeddedStatic" instead, it is much more powerful.
+--
 -- Nota Bene: if you replace the scaffolded 'static' call in Settings/StaticFiles.hs
 -- you will need to change the scaffolded addStaticContent.  Otherwise, some of your
 -- assets will be 404'ed.  This is because by default yesod will generate compile those
@@ -222,7 +226,7 @@ getFileListPieces = flip evalStateT M.empty . flip go id
 -- definitions would be created:
 --
 -- > style_css    = StaticRoute ["style.css"]    []
--- > js_script_js = StaticRoute ["js/script.js"] []
+-- > js_script_js = StaticRoute ["js", "script.js"] []
 --
 -- Note that dots (@.@), dashes (@-@) and slashes (@\/@) are
 -- replaced by underscores (@\_@) to create valid Haskell
@@ -474,10 +478,13 @@ data CombineSettings = CombineSettings
 instance Default CombineSettings where
     def = CombineSettings
         { csStaticDir = "static"
+        {- Disabled due to: https://github.com/yesodweb/yesod/issues/623
         , csCssPostProcess = \fps ->
               either (error . (errorIntro fps)) (return . TLE.encodeUtf8)
             . flip luciusRTMinified []
             . TLE.decodeUtf8
+        -}
+        , csCssPostProcess = const return
         , csJsPostProcess = const return
            -- FIXME The following borders on a hack. With combining of files,
            -- the final location of the CSS is no longer fixed, so relative
